@@ -44,25 +44,21 @@ my $grammar = q{
   ;
 
   %%
-  sub _Error { die "Syntax error near ".($_[0]->YYCurval?$_[0]->YYCurval:"end of file")."\n" }
+  use base q{Parse::Eyapp::TailSupport};
 
-  sub _Lexer {
-    my($parser)=shift; # The parser object
+  __PACKAGE__->lexer( sub {
+      my($parser)=shift; # The parser object
 
-    for ($parser->YYData->{INPUT}) { # Topicalize
-      m{\G\s+}gc;
-      $_ eq '' and return('',undef);
-      m{\G([0-9]+(?:\.[0-9]+)?)}gc and return('NUM',$1);
-      m{\G([A-Za-z][A-Za-z0-9_]*)}gc and return('VAR',$1);
-      m{\G(.)}gcs and return($1,$1);
+      for (${$parser->input}) { # Topicalize
+        m{\G\s+}gc;
+        $_ eq '' and return('',undef);
+        m{\G([0-9]+(?:\.[0-9]+)?)}gc and return('NUM',$1);
+        m{\G([A-Za-z][A-Za-z0-9_]*)}gc and return('VAR',$1);
+        m{\G(.)}gcs and return($1,$1);
+      }
+      return('',undef);
     }
-    return('',undef);
-  }
-
-  sub Run {
-      my($self)=shift;
-      $self->YYParse( yylex => \&_Lexer, yyerror => \&_Error, );
-  }
+  );
 }; # end grammar
 
 our (@all, $uminus);
@@ -73,7 +69,7 @@ Parse::Eyapp->new_grammar( # Create the parser package/class
   firstline=>7       # String $grammar starts at line 7 (for error diagnostics)
 ); 
 my $parser = Calc->new();                # Create a parser
-$parser->YYData->{INPUT} = "2*-3+b*0;--2\n"; # Set the input
+$parser->input(\"2*-3+b*0;--2\n");       # Set the input
 my $t = $parser->Run;                    # Parse it!
 local $Parse::Eyapp::Node::INDENT=2;
 print "Syntax Tree:",$t->str;
@@ -93,7 +89,7 @@ my $p = Parse::Eyapp::Treeregexp->new( STRING => q{
     zero_times_whatever: TIMES(NUM($x), .) and { $x->{attr} == 0 } => { $_[0] = $NUM }
     whatever_times_zero: TIMES(., NUM($x)) and { $x->{attr} == 0 } => { $_[0] = $NUM }
   },
-  OUTPUTFILE=> 'main.pm'
+  #OUTPUTFILE=> 'main.pm'
 );
 $p->generate(); # Create the tranformations
 
