@@ -1,6 +1,6 @@
 ########################################################################################
 #
-#    This file was generated using Parse::Eyapp version 1.150.
+#    This file was generated using Parse::Eyapp version 1.151.
 #
 # (c) Parse::Yapp Copyright 1998-2001 Francois Desarmenien.
 # (c) Parse::Eyapp Copyright 2006-2008 Casiano Rodriguez-Leon. Universidad de La Laguna.
@@ -236,67 +236,67 @@ sub new {
 
   warn $warnmessage unless __PACKAGE__->isa('Parse::Eyapp::Driver'); 
   my($self)=$class->SUPER::new( 
-    yyversion => '1.150',
+    yyversion => '1.151',
     yyGRAMMAR  =>
 [
-  [ _SUPERSTART => '$start', [ 'treeregexplist', '$end' ], 0 ],
-  [ _STAR_LIST => 'STAR-1', [ 'STAR-1', 'treeregexp' ], 0 ],
-  [ _STAR_LIST => 'STAR-1', [  ], 0 ],
-  [ treeregexplist_3 => 'treeregexplist', [ 'STAR-1' ], 0 ],
-  [ _PAREN => 'PAREN-2', [ '=>', 'CODE' ], 0 ],
-  [ _OPTIONAL => 'OPTIONAL-3', [ 'PAREN-2' ], 0 ],
-  [ _OPTIONAL => 'OPTIONAL-3', [  ], 0 ],
-  [ _PLUS_LIST => 'PLUS-4', [ 'PLUS-4', 'IDENT' ], 0 ],
-  [ _PLUS_LIST => 'PLUS-4', [ 'IDENT' ], 0 ],
-  [ treeregexp_9 => 'treeregexp', [ 'IDENT', ':', 'treereg', 'OPTIONAL-3' ], 0 ],
-  [ treeregexp_10 => 'treeregexp', [ 'CODE' ], 0 ],
-  [ treeregexp_11 => 'treeregexp', [ 'IDENT', '=', 'PLUS-4', ';' ], 0 ],
-  [ treeregexp_12 => 'treeregexp', [ 'REGEXP' ], 0 ],
-  [ _PAREN => 'PAREN-5', [ 'and', 'CODE' ], 0 ],
-  [ _OPTIONAL => 'OPTIONAL-6', [ 'PAREN-5' ], 0 ],
-  [ _OPTIONAL => 'OPTIONAL-6', [  ], 0 ],
-  [ _PAREN => 'PAREN-7', [ ':', 'IDENT' ], 0 ],
-  [ _OPTIONAL => 'OPTIONAL-8', [ 'PAREN-7' ], 0 ],
-  [ _OPTIONAL => 'OPTIONAL-8', [  ], 0 ],
-  [ _PAREN => 'PAREN-9', [ 'and', 'CODE' ], 0 ],
-  [ _OPTIONAL => 'OPTIONAL-10', [ 'PAREN-9' ], 0 ],
-  [ _OPTIONAL => 'OPTIONAL-10', [  ], 0 ],
-  [ _PAREN => 'PAREN-11', [ 'and', 'CODE' ], 0 ],
-  [ _OPTIONAL => 'OPTIONAL-12', [ 'PAREN-11' ], 0 ],
-  [ _OPTIONAL => 'OPTIONAL-12', [  ], 0 ],
-  [ _PAREN => 'PAREN-13', [ 'and', 'CODE' ], 0 ],
-  [ _OPTIONAL => 'OPTIONAL-14', [ 'PAREN-13' ], 0 ],
-  [ _OPTIONAL => 'OPTIONAL-14', [  ], 0 ],
-  [ _PAREN => 'PAREN-15', [ 'and', 'CODE' ], 0 ],
-  [ _OPTIONAL => 'OPTIONAL-16', [ 'PAREN-15' ], 0 ],
-  [ _OPTIONAL => 'OPTIONAL-16', [  ], 0 ],
-  [ _PAREN => 'PAREN-17', [ ':', 'IDENT' ], 0 ],
-  [ _OPTIONAL => 'OPTIONAL-18', [ 'PAREN-17' ], 0 ],
-  [ _OPTIONAL => 'OPTIONAL-18', [  ], 0 ],
-  [ _PAREN => 'PAREN-19', [ 'and', 'CODE' ], 0 ],
-  [ _OPTIONAL => 'OPTIONAL-20', [ 'PAREN-19' ], 0 ],
-  [ _OPTIONAL => 'OPTIONAL-20', [  ], 0 ],
-  [ _PAREN => 'PAREN-21', [ 'and', 'CODE' ], 0 ],
-  [ _OPTIONAL => 'OPTIONAL-22', [ 'PAREN-21' ], 0 ],
-  [ _OPTIONAL => 'OPTIONAL-22', [  ], 0 ],
-  [ _PAREN => 'PAREN-23', [ 'and', 'CODE' ], 0 ],
-  [ _OPTIONAL => 'OPTIONAL-24', [ 'PAREN-23' ], 0 ],
-  [ _OPTIONAL => 'OPTIONAL-24', [  ], 0 ],
-  [ treereg_43 => 'treereg', [ 'IDENT', '(', 'childlist', ')', 'OPTIONAL-6' ], 0 ],
-  [ treereg_44 => 'treereg', [ 'REGEXP', 'OPTIONAL-8', '(', 'childlist', ')', 'OPTIONAL-10' ], 0 ],
-  [ treereg_45 => 'treereg', [ 'SCALAR', '(', 'childlist', ')', 'OPTIONAL-12' ], 0 ],
-  [ treereg_46 => 'treereg', [ '.', '(', 'childlist', ')', 'OPTIONAL-14' ], 0 ],
-  [ treereg_47 => 'treereg', [ 'IDENT', 'OPTIONAL-16' ], 0 ],
-  [ treereg_48 => 'treereg', [ 'REGEXP', 'OPTIONAL-18', 'OPTIONAL-20' ], 0 ],
-  [ treereg_49 => 'treereg', [ 'SCALAR', 'OPTIONAL-22' ], 0 ],
-  [ treereg_50 => 'treereg', [ '.', 'OPTIONAL-24' ], 0 ],
-  [ treereg_51 => 'treereg', [ 'ARRAY' ], 0 ],
-  [ treereg_52 => 'treereg', [ '*' ], 0 ],
-  [ _STAR_LIST => 'STAR-25', [ 'STAR-25', ',', 'treereg' ], 0 ],
-  [ _STAR_LIST => 'STAR-25', [ 'treereg' ], 0 ],
-  [ _STAR_LIST => 'STAR-26', [ 'STAR-25' ], 0 ],
-  [ _STAR_LIST => 'STAR-26', [  ], 0 ],
-  [ childlist_57 => 'childlist', [ 'STAR-26' ], 0 ],
+  [ '_SUPERSTART' => '$start', [ 'treeregexplist', '$end' ], 0 ],
+  [ '_STAR_LIST' => 'STAR-1', [ 'STAR-1', 'treeregexp' ], 0 ],
+  [ '_STAR_LIST' => 'STAR-1', [  ], 0 ],
+  [ 'treeregexplist_3' => 'treeregexplist', [ 'STAR-1' ], 0 ],
+  [ '_PAREN' => 'PAREN-2', [ '=>', 'CODE' ], 0 ],
+  [ '_OPTIONAL' => 'OPTIONAL-3', [ 'PAREN-2' ], 0 ],
+  [ '_OPTIONAL' => 'OPTIONAL-3', [  ], 0 ],
+  [ '_PLUS_LIST' => 'PLUS-4', [ 'PLUS-4', 'IDENT' ], 0 ],
+  [ '_PLUS_LIST' => 'PLUS-4', [ 'IDENT' ], 0 ],
+  [ 'treeregexp_9' => 'treeregexp', [ 'IDENT', ':', 'treereg', 'OPTIONAL-3' ], 0 ],
+  [ 'treeregexp_10' => 'treeregexp', [ 'CODE' ], 0 ],
+  [ 'treeregexp_11' => 'treeregexp', [ 'IDENT', '=', 'PLUS-4', ';' ], 0 ],
+  [ 'treeregexp_12' => 'treeregexp', [ 'REGEXP' ], 0 ],
+  [ '_PAREN' => 'PAREN-5', [ 'and', 'CODE' ], 0 ],
+  [ '_OPTIONAL' => 'OPTIONAL-6', [ 'PAREN-5' ], 0 ],
+  [ '_OPTIONAL' => 'OPTIONAL-6', [  ], 0 ],
+  [ '_PAREN' => 'PAREN-7', [ ':', 'IDENT' ], 0 ],
+  [ '_OPTIONAL' => 'OPTIONAL-8', [ 'PAREN-7' ], 0 ],
+  [ '_OPTIONAL' => 'OPTIONAL-8', [  ], 0 ],
+  [ '_PAREN' => 'PAREN-9', [ 'and', 'CODE' ], 0 ],
+  [ '_OPTIONAL' => 'OPTIONAL-10', [ 'PAREN-9' ], 0 ],
+  [ '_OPTIONAL' => 'OPTIONAL-10', [  ], 0 ],
+  [ '_PAREN' => 'PAREN-11', [ 'and', 'CODE' ], 0 ],
+  [ '_OPTIONAL' => 'OPTIONAL-12', [ 'PAREN-11' ], 0 ],
+  [ '_OPTIONAL' => 'OPTIONAL-12', [  ], 0 ],
+  [ '_PAREN' => 'PAREN-13', [ 'and', 'CODE' ], 0 ],
+  [ '_OPTIONAL' => 'OPTIONAL-14', [ 'PAREN-13' ], 0 ],
+  [ '_OPTIONAL' => 'OPTIONAL-14', [  ], 0 ],
+  [ '_PAREN' => 'PAREN-15', [ 'and', 'CODE' ], 0 ],
+  [ '_OPTIONAL' => 'OPTIONAL-16', [ 'PAREN-15' ], 0 ],
+  [ '_OPTIONAL' => 'OPTIONAL-16', [  ], 0 ],
+  [ '_PAREN' => 'PAREN-17', [ ':', 'IDENT' ], 0 ],
+  [ '_OPTIONAL' => 'OPTIONAL-18', [ 'PAREN-17' ], 0 ],
+  [ '_OPTIONAL' => 'OPTIONAL-18', [  ], 0 ],
+  [ '_PAREN' => 'PAREN-19', [ 'and', 'CODE' ], 0 ],
+  [ '_OPTIONAL' => 'OPTIONAL-20', [ 'PAREN-19' ], 0 ],
+  [ '_OPTIONAL' => 'OPTIONAL-20', [  ], 0 ],
+  [ '_PAREN' => 'PAREN-21', [ 'and', 'CODE' ], 0 ],
+  [ '_OPTIONAL' => 'OPTIONAL-22', [ 'PAREN-21' ], 0 ],
+  [ '_OPTIONAL' => 'OPTIONAL-22', [  ], 0 ],
+  [ '_PAREN' => 'PAREN-23', [ 'and', 'CODE' ], 0 ],
+  [ '_OPTIONAL' => 'OPTIONAL-24', [ 'PAREN-23' ], 0 ],
+  [ '_OPTIONAL' => 'OPTIONAL-24', [  ], 0 ],
+  [ 'treereg_43' => 'treereg', [ 'IDENT', '(', 'childlist', ')', 'OPTIONAL-6' ], 0 ],
+  [ 'treereg_44' => 'treereg', [ 'REGEXP', 'OPTIONAL-8', '(', 'childlist', ')', 'OPTIONAL-10' ], 0 ],
+  [ 'treereg_45' => 'treereg', [ 'SCALAR', '(', 'childlist', ')', 'OPTIONAL-12' ], 0 ],
+  [ 'treereg_46' => 'treereg', [ '.', '(', 'childlist', ')', 'OPTIONAL-14' ], 0 ],
+  [ 'treereg_47' => 'treereg', [ 'IDENT', 'OPTIONAL-16' ], 0 ],
+  [ 'treereg_48' => 'treereg', [ 'REGEXP', 'OPTIONAL-18', 'OPTIONAL-20' ], 0 ],
+  [ 'treereg_49' => 'treereg', [ 'SCALAR', 'OPTIONAL-22' ], 0 ],
+  [ 'treereg_50' => 'treereg', [ '.', 'OPTIONAL-24' ], 0 ],
+  [ 'treereg_51' => 'treereg', [ 'ARRAY' ], 0 ],
+  [ 'treereg_52' => 'treereg', [ '*' ], 0 ],
+  [ '_STAR_LIST' => 'STAR-25', [ 'STAR-25', ',', 'treereg' ], 0 ],
+  [ '_STAR_LIST' => 'STAR-25', [ 'treereg' ], 0 ],
+  [ '_STAR_LIST' => 'STAR-26', [ 'STAR-25' ], 0 ],
+  [ '_STAR_LIST' => 'STAR-26', [  ], 0 ],
+  [ 'childlist_57' => 'childlist', [ 'STAR-26' ], 0 ],
 ],
     yyTERMS  =>
 { '' => { ISSEMANTIC => 0 },
@@ -1135,25 +1135,65 @@ sub {
   );
   bless($self,$class);
 
-  $self->make_node_classes( qw{TERMINAL _OPTIONAL _STAR_LIST _PLUS_LIST 
-         _SUPERSTART
-         treeregexplist_3
-         _PAREN
-         treeregexp_9
-         treeregexp_10
-         treeregexp_11
-         treeregexp_12
-         treereg_43
-         treereg_44
-         treereg_45
-         treereg_46
-         treereg_47
-         treereg_48
-         treereg_49
-         treereg_50
-         treereg_51
-         treereg_52
-         childlist_57} );
+  $self->make_node_classes('TERMINAL', '_OPTIONAL', '_STAR_LIST', '_PLUS_LIST', 
+         '_SUPERSTART', 
+         '_STAR_LIST', 
+         '_STAR_LIST', 
+         'treeregexplist_3', 
+         '_PAREN', 
+         '_OPTIONAL', 
+         '_OPTIONAL', 
+         '_PLUS_LIST', 
+         '_PLUS_LIST', 
+         'treeregexp_9', 
+         'treeregexp_10', 
+         'treeregexp_11', 
+         'treeregexp_12', 
+         '_PAREN', 
+         '_OPTIONAL', 
+         '_OPTIONAL', 
+         '_PAREN', 
+         '_OPTIONAL', 
+         '_OPTIONAL', 
+         '_PAREN', 
+         '_OPTIONAL', 
+         '_OPTIONAL', 
+         '_PAREN', 
+         '_OPTIONAL', 
+         '_OPTIONAL', 
+         '_PAREN', 
+         '_OPTIONAL', 
+         '_OPTIONAL', 
+         '_PAREN', 
+         '_OPTIONAL', 
+         '_OPTIONAL', 
+         '_PAREN', 
+         '_OPTIONAL', 
+         '_OPTIONAL', 
+         '_PAREN', 
+         '_OPTIONAL', 
+         '_OPTIONAL', 
+         '_PAREN', 
+         '_OPTIONAL', 
+         '_OPTIONAL', 
+         '_PAREN', 
+         '_OPTIONAL', 
+         '_OPTIONAL', 
+         'treereg_43', 
+         'treereg_44', 
+         'treereg_45', 
+         'treereg_46', 
+         'treereg_47', 
+         'treereg_48', 
+         'treereg_49', 
+         'treereg_50', 
+         'treereg_51', 
+         'treereg_52', 
+         '_STAR_LIST', 
+         '_STAR_LIST', 
+         '_STAR_LIST', 
+         '_STAR_LIST', 
+         'childlist_57', );
   $self;
 }
 
